@@ -88,6 +88,8 @@ on_slide <- function(x, index) {
 #' @description Remove a slide from a pptx presentation.
 #' @param x an rpptx object
 #' @param index slide index, default to current slide position.
+#' @param rm_images if TRUE (defaults to FALSE), images presented in
+#' the slide to remove are also removed from the file.
 #' @note cursor is set on the last slide.
 #' @examples
 #' my_pres <- read_pptx()
@@ -95,7 +97,7 @@ on_slide <- function(x, index) {
 #' my_pres <- remove_slide(my_pres)
 #' @family functions slide manipulation
 #' @seealso [read_pptx()], [ph_with()], [ph_remove()]
-remove_slide <- function(x, index = NULL) {
+remove_slide <- function(x, index = NULL, rm_images = FALSE) {
   l_ <- length(x)
   if (l_ < 1) {
     stop("presentation contains no slide to delete", call. = FALSE)
@@ -111,6 +113,13 @@ remove_slide <- function(x, index = NULL) {
   filename <- basename(x$presentation$slide_data()$target[index])
   location <- which(x$slide$get_metadata()$name %in% filename)
 
+  if (rm_images) {
+    media_files <- pptx_summary(x)$media_file
+    if (length(media_files)) {
+      unlink(file.path(x$package_dir, media_files), force = TRUE)
+    }
+  }
+
   del_file <- x$slide$remove_slide(location)
 
   # update presentation elements
@@ -180,8 +189,8 @@ pptx_fortify_slides <- function(x) {
     process_links(slide, type = "pml")
 
     cnvpr <- xml_find_all(slide$get(), "//p:cNvPr")
-    for(i in seq_along(cnvpr)){
-      xml_attr( cnvpr[[i]], "id") <- i
+    for (i in seq_along(cnvpr)) {
+      xml_attr(cnvpr[[i]], "id") <- i
     }
   }
 
@@ -219,7 +228,9 @@ shape_properties_tags <- function(left = 0, top = 0, width = 3, height = 3,
     ph <- "<p:ph/>"
   }
 
-  str <- "<p:nvSpPr><p:cNvPr id=\"0\" name=\"%s\"/><p:cNvSpPr><a:spLocks noGrp=\"1\"/></p:cNvSpPr><p:nvPr>%s</p:nvPr></p:nvSpPr><p:spPr>%s%s%s%s</p:spPr>"
+  randomid <- officer::uuid_generate()
 
-  sprintf(str, label, ph, xfrm_str, geom_str, bg_str, ln_str)
+  str <- "<p:nvSpPr><p:cNvPr id=\"%s\" name=\"%s\"/><p:cNvSpPr><a:spLocks noGrp=\"1\"/></p:cNvSpPr><p:nvPr>%s</p:nvPr></p:nvSpPr><p:spPr>%s%s%s%s</p:spPr>"
+
+  sprintf(str, randomid, label, ph, xfrm_str, geom_str, bg_str, ln_str)
 }
